AutoDisposePaginatedStreamNotifier<Entity, Param> class
abstract
AutoDispose variant - In Riverpod 3.0, all notifiers extend Notifier. Auto-dispose behavior is controlled by the provider type.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ PaginatedState<
Entity> -
The value currently exposed by this notifier.
getter/setter pairinherited
-
stateOrNull
→ PaginatedState<
Entity> ? -
The value currently exposed by this
Notifier.no setterinherited
Methods
-
build(
) → PaginatedState< Entity> - do not override in child classes, use prepareForBuild instead
-
cancelThrottle(
{String throttleIdentifier = ''}) → void -
Cancels if throttling is in progress
inherited
-
clearGlobalLoading(
) → void -
Clear BaseLoadingIndicator
inherited
-
debounce(
{Duration duration = const Duration(milliseconds: 500)}) → Future< void> -
Wait to collect multiple method calls for certain duration before allowing only one method call to proceed
inherited
-
getInitialList(
[Param? param]) → Future< void> -
inherited
-
getListStreamOrFailure(
int page, [Param? parameter]) → PaginatedStreamFailureOr< Entity> -
inherited
-
getNextPage(
) → Future< void> -
inherited
-
listenSelf(
void listener(PaginatedState< Entity> ? previous, PaginatedState<Entity> next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
U> (ProviderListenable< U> provider, void invokeFunction(U? previous, U next), {bool skipUpdateCondition(U? previous, U next)?}) → void -
Subscribe to another notifier's state changes
inherited
-
prepareForBuild(
) → ({PaginatedState< Entity> initialState, bool useGlobalFailure}) -
refresh(
) → Future< void> -
inherited
-
runBuild(
) → void -
Executes
Notifier.build.inherited -
setGlobalFailure(
Failure? failure) → void -
inherited
-
setGlobalInfo(
GlobalInfo? globalInfo) → void -
inherited
-
showGlobalLoading(
) → void -
Show BaseLoadingIndicator above the entire app
inherited
-
throttle(
Future< void> function(), {Duration duration = const Duration(milliseconds: 500), bool waitForFunction = true, String throttleIdentifier = ''}) → Future<void> -
Execute given function and then block further executing of the same function for certain duration.
waitForFunctionif set to true it will wait if function finishes after provided duration delay, otherwise will finish immediately after given durationinherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
PaginatedState< Entity> previous, PaginatedState<Entity> next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited