riverpod_architecture library
Classes
-
AutoDisposeFamilySimpleNotifier<
T, Arg> - AutoDisposeFamily variant - In Riverpod 3.0, family notifiers accept an argument via constructor.
-
AutoDisposeSimpleNotifier<
T> - AutoDispose variant - In Riverpod 3.0, all notifiers extend Notifier. Auto-dispose behavior is controlled by the provider type.
- BaseLoadingIndicator
- BaseWidget
- ErrorResolver
- Failure
- Failure class that represents some kind of error that occurs in the app and being passed to UI
-
FamilySimpleNotifier<
T, Arg> - Family variant - In Riverpod 3.0, family notifiers accept an argument via constructor.
- GlobalFailureNotifier
- GlobalInfo
- GlobalInfo class that represents some kind of info that occurs in the app and being passed to UI
- GlobalInfoNotifier
- GlobalLoadingNotifier
-
PaginatedList<
T> -
PaginatedListView<
Entity, Param, Arg> -
SimpleNotifier<
T>
Enums
- GlobalInfoStatus
- GlobalInfoStatus enum that represents type of Global Info
- PaginatedListViewType
Mixins
- ErrorToFailureMixin
-
Executes received
functionwithin a try-catch block.
Properties
-
globalFailureProvider
→ NotifierProvider<
GlobalFailureNotifier, Failure?> -
globalFailureProvider can be used to show the failure without updating BaseNotifier state.
final
-
globalInfoProvider
→ NotifierProvider<
GlobalInfoNotifier, GlobalInfo?> -
globalInfoProvider can be used to show any info without updating BaseNotifier state.
final
-
globalLoadingProvider
→ NotifierProvider<
GlobalLoadingNotifier, bool> -
globalLoadingProvider can be used to show the loading indicator without updating BaseNotifier
state. The entire app is wrapped in BaseWidget and BaseLoadingIndicator can be shown above entire
app by simply calling
showGlobalLoading. To hide BaseLoadingIndicator simply callclearGlobalLoadingfinal
Typedefs
-
EitherFailureOr<
T> = Future< Either< Failure, T> > -
EntityMapper<
Entity, Response> = Entity Function(Response) -
FormMapper<
Entity> = Entity Function(Map< String, dynamic> ) -
FormWithOptionMapper<
Entity, Option> = Entity Function(Map< String, dynamic> , Option) -
PaginatedEitherFailureOr<
Entity> = Future< Either< Failure, PaginatedList< >Entity> > -
RequestMapper<
Request, Entity> = Request Function(Entity) -
StreamFailureOr<
T> = Stream< Either< Failure, T> >